package com.ruoyi.bst.hardwareVersion.service;

import java.util.List;

import com.ruoyi.bst.hardwareVersion.domain.HardwareVersion;
import com.ruoyi.bst.hardwareVersion.domain.HardwareVersionQuery;
import com.ruoyi.bst.hardwareVersion.domain.HardwareVersionVO;
import com.ruoyi.bst.hardwareVersion.domain.vo.HardwareVersionNameVO;

/**
 * 硬件版本Service接口
 *
 * @author ruoyi
 * @date 2025-04-07
 */
public interface HardwareVersionService
{
    /**
     * 查询硬件版本
     *
     * @param id 硬件版本主键
     * @return 硬件版本
     */
    public HardwareVersionVO selectHardwareVersionById(Long id);

    /**
     * 查询硬件版本列表
     *
     * @param hardwareVersion 硬件版本
     * @return 硬件版本集合
     */
    public List<HardwareVersionVO> selectHardwareVersionList(HardwareVersionQuery hardwareVersion);

    /**
     * 新增硬件版本
     *
     * @param hardwareVersion 硬件版本
     * @return 结果
     */
    public int insertHardwareVersion(HardwareVersion hardwareVersion);

    /**
     * 修改硬件版本
     *
     * @param hardwareVersion 硬件版本
     * @return 结果
     */
    public int updateHardwareVersion(HardwareVersion hardwareVersion);

    /**
     * 批量删除硬件版本
     *
     * @param ids 需要删除的硬件版本主键集合
     * @return 结果
     */
    public int deleteHardwareVersionByIds(Long[] ids);


    List<HardwareVersionVO> computeNumber(HardwareVersionQuery query);

    List<HardwareVersionVO> selectBoundCount(HardwareVersionQuery query);

    List<HardwareVersionVO> selectUnBoundCount(HardwareVersionQuery query);

    /**
     * 查询所有硬件版本名称
     * @return
     */
    public List<HardwareVersionNameVO> selectAllNames();

}
